@@ -7,17 +7,21 @@ from subprocess import Popen
 from optparse import OptionParser
 
 
-def fire_in_folder(folder, args):
+def fire_in_folder(folder, args, options):
     for file in os.listdir(folder):
         path = os.path.join(folder, file)
         if os.path.isdir(path) and not file.startswith('.'): # TODO: linux specific
+            if options.verbose:
+                print '--- running in folder %s ---' % path
             p = Popen(
                 args=args,
                 cwd=path,
             )
             p.wait()
+            if options.verbose:
+                print '--- end --- '
 
-def main():
+def main(*a, **kw):
     parser = OptionParser(usage="fire_in_folders [options] command\n")
     parser.add_option(
         "-s",
@@ -27,6 +31,13 @@ def main():
         type="string",
         default="src",
         help="destination folder where to execute command in all subfolders")
+    parser.add_option(
+        "-q",
+        "--quiet",
+        action="store_false",
+        dest="verbose",
+        default=True,
+        help="do not display extra information")
 
     (options, args) = parser.parse_args()
 
@@ -38,7 +49,7 @@ def main():
     if not os.path.exists(target_path):
         parser.error('Folder does not exist: %s' % target_path)
 
-    fire_in_folder(target_path, args)
+    fire_in_folder(target_path, args, options)
 
 
 if __name__ == '__main__':
